@@ -5,8 +5,7 @@ INSTALLED_APPS = [
    'django.contrib.redirects',
    'django.contrib.sessions',
    'django.contrib.sites',
-   'django.contrib.sitemap'
-   's',
+   'django.contrib.sitemaps',
    'django.contrib.humanize',
    'django.contrib.comments',
    'django.contrib.admin',
